==> haskell-rio-0.1.22.0-114-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rio
version:              0.1.22.0
visibility:           public
id:                   rio-0.1.22.0-43WSIgFMZCwIMDzz866nlj
key:                  rio-0.1.22.0-43WSIgFMZCwIMDzz866nlj
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio#readme
synopsis:             A standard library for Haskell
description:
    See README and Haddocks at <https://www.stackage.org/package/rio>

category:             Control
abi:                  37c5721b20def7f1c44bf9cb67f5a0cf
exposed:              True
exposed-modules:
    RIO RIO.ByteString RIO.ByteString.Lazy RIO.ByteString.Lazy.Partial
    RIO.ByteString.Partial RIO.Char RIO.Char.Partial RIO.Deque
    RIO.Directory RIO.File RIO.FilePath RIO.HashMap RIO.HashMap.Partial
    RIO.HashSet RIO.Lens RIO.List RIO.List.Partial RIO.Map
    RIO.Map.Partial RIO.Map.Unchecked RIO.NonEmpty RIO.NonEmpty.Partial
    RIO.Partial RIO.Prelude RIO.Prelude.Simple RIO.Prelude.Types
    RIO.Process RIO.Seq RIO.Set RIO.Set.Partial RIO.Set.Unchecked
    RIO.State RIO.Text RIO.Text.Lazy RIO.Text.Lazy.Partial
    RIO.Text.Partial RIO.Time RIO.Vector RIO.Vector.Boxed
    RIO.Vector.Boxed.Partial RIO.Vector.Boxed.Unsafe RIO.Vector.Partial
    RIO.Vector.Storable RIO.Vector.Storable.Partial
    RIO.Vector.Storable.Unsafe RIO.Vector.Unboxed
    RIO.Vector.Unboxed.Partial RIO.Vector.Unboxed.Unsafe
    RIO.Vector.Unsafe RIO.Writer

hidden-modules:
    RIO.Prelude.Display RIO.Prelude.Exit RIO.Prelude.Extra
    RIO.Prelude.IO RIO.Prelude.Lens RIO.Prelude.Logger
    RIO.Prelude.Reexports RIO.Prelude.Renames RIO.Prelude.RIO
    RIO.Prelude.Text RIO.Prelude.Trace RIO.Prelude.URef

import-dirs:          /usr/lib/ghc-9.2.8/site-local/rio-0.1.22.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/rio-0.1.22.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rio
hs-libraries:         HSrio-0.1.22.0-43WSIgFMZCwIMDzz866nlj
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    deepseq-1.4.6.1 directory-1.3.6.2 exceptions-0.10.4
    filepath-1.4.2.2 hashable-1.4.3.0-4gqtyFKn8Wu9OwsZtyYGdt
    microlens-0.4.13.1-HPplyG5VOciEIF62YegSgA
    microlens-mtl-0.2.0.3-K2j2D46quth4CyQpetHsMp mtl-2.2.2
    primitive-0.7.4.0-IuAkHfsD4drDvErljoigXB process-1.6.16.0
    text-1.2.5.0 time-1.11.1.1
    typed-process-0.2.11.1-LEP73JrChKL9DD74cE137j unix-2.7.2.2
    unliftio-0.2.25.0-INoatlssrBVAcEPI6HA5Cp
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn
    unordered-containers-0.2.20-3nVNqHdmWG59aZRDnxmFox
    vector-0.13.1.0-FuSYSqJEiCU51oStZmHlCe

haddock-interfaces:   /usr/share/doc/haskell-rio/html/rio.haddock
haddock-html:         /usr/share/doc/haskell-rio/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rio-0.1.22.0-116-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rio
version:              0.1.22.0
visibility:           public
id:                   rio-0.1.22.0-2KZU4ov6TudC8bo5bbTPJH
key:                  rio-0.1.22.0-2KZU4ov6TudC8bo5bbTPJH
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio#readme
synopsis:             A standard library for Haskell
description:
    See README and Haddocks at <https://www.stackage.org/package/rio>

category:             Control
abi:                  26803a1aa5ee336509c954c6d43fd5db
exposed:              True
exposed-modules:
    RIO RIO.ByteString RIO.ByteString.Lazy RIO.ByteString.Lazy.Partial
    RIO.ByteString.Partial RIO.Char RIO.Char.Partial RIO.Deque
    RIO.Directory RIO.File RIO.FilePath RIO.HashMap RIO.HashMap.Partial
    RIO.HashSet RIO.Lens RIO.List RIO.List.Partial RIO.Map
    RIO.Map.Partial RIO.Map.Unchecked RIO.NonEmpty RIO.NonEmpty.Partial
    RIO.Partial RIO.Prelude RIO.Prelude.Simple RIO.Prelude.Types
    RIO.Process RIO.Seq RIO.Set RIO.Set.Partial RIO.Set.Unchecked
    RIO.State RIO.Text RIO.Text.Lazy RIO.Text.Lazy.Partial
    RIO.Text.Partial RIO.Time RIO.Vector RIO.Vector.Boxed
    RIO.Vector.Boxed.Partial RIO.Vector.Boxed.Unsafe RIO.Vector.Partial
    RIO.Vector.Storable RIO.Vector.Storable.Partial
    RIO.Vector.Storable.Unsafe RIO.Vector.Unboxed
    RIO.Vector.Unboxed.Partial RIO.Vector.Unboxed.Unsafe
    RIO.Vector.Unsafe RIO.Writer

hidden-modules:
    RIO.Prelude.Display RIO.Prelude.Exit RIO.Prelude.Extra
    RIO.Prelude.IO RIO.Prelude.Lens RIO.Prelude.Logger
    RIO.Prelude.Reexports RIO.Prelude.Renames RIO.Prelude.RIO
    RIO.Prelude.Text RIO.Prelude.Trace RIO.Prelude.URef

import-dirs:          /usr/lib/ghc-9.2.8/site-local/rio-0.1.22.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/rio-0.1.22.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rio
hs-libraries:         HSrio-0.1.22.0-2KZU4ov6TudC8bo5bbTPJH
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    deepseq-1.4.6.1 directory-1.3.6.2 exceptions-0.10.4
    filepath-1.4.2.2 hashable-1.4.4.0-4qKxN3FrXfb4sBBhra6sdO
    microlens-0.4.13.1-HPplyG5VOciEIF62YegSgA
    microlens-mtl-0.2.0.3-K2j2D46quth4CyQpetHsMp mtl-2.2.2
    primitive-0.7.4.0-FVB8RLw7kwa2mbgh0KVHMG process-1.6.16.0
    text-1.2.5.0 time-1.11.1.1
    typed-process-0.2.11.1-3t9PHBngNXJLWpdWVs4jOA unix-2.7.2.2
    unliftio-0.2.25.0-JnPcGA33aKnBemmBAMXZcn
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn
    unordered-containers-0.2.20-A3yVeSkjdcGAgke7XFfywE
    vector-0.13.1.0-G7FmTKS6EuOC4CxSRTf251

haddock-interfaces:   /usr/share/doc/haskell-rio/html/rio.haddock
haddock-html:         /usr/share/doc/haskell-rio/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
